#ifndef __fndcx_h
#define __fndcx_h
/*****************************************************************************/
/*                                                                           */
/*    COPYRIGHT : 5765 - 196                                                 */
/*    (C) COPYRIGHT IBM CORP 1993                                            */
/*    ALL RIGHTS RESERVED                                                    */
/*    LICENSED MATERIALS - PROPERTY OF IBM                                   */
/*                                                                           */
/* Product:         NetView Distribution Manager/6000                        */
/*                                                                           */
/* Module:          FNDCX.H                                                  */
/*                                                                           */
/* Component:       Server/DACA User-Exit/Notification Routines Header File  */
/*                                                                           */
/* Description:     This module contains the function prototypes for the     */
/*                  Server and DACA User-Exit and Notification routines.     */
/*                  The following routines are provided                      */
/*                                                                           */
/*                  - cx_daca_filename  modify local filename                */
/*                  - cx_daca_report    when request received                */
/*                  - cx_daca_request   before report sent                   */
/*                  - sx_server_request when a request is scheduled          */
/*                  - sx_server_report  when a report is received            */
/*                  - cx_mount_fs       mount fs                             */
/*                  - cx_unmount_fs     unmount fs                           */
/*                                                                           */
/* Prerequisites: fndhdr.h                                                   */
/*                fndshrr.h                                                  */
/*                                                                           */
/*****************************************************************************/


#define    RR_INFO_FILLER_SIZE       36

/*****************************************************************************/
/* Structure: RR_INFO                                                        */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure contains an entry from the scheduler queue.              */
/*                                                                           */
/* Fields:                                                                   */
/*   req_id                                                                  */
/*     specifies the request identifier as returned by CLIM and GUI.         */
/*   subreq_id                                                               */
/*     Identifies the entry id inside a plan.                                */
/*     If req_id identifies a single request, subreq-id is filled with       */
/*     binary zeroes.                                                        */
/*   sched_info                                                              */
/*     this structure contains all scheduling parameters.                    */
/*   seq_no                                                                  */
/*     Request Sequence number. It is used to correlate reports with the     */
/*     original requests.                                                    */
/*     This field together with submit_time, originator and destination      */
/*     forms what is known as SNA correlator ans is used in SNA/DS type of   */
/*     connections.                                                          */
/*   submit_time                                                             */
/*     time when the request was submitted                                   */
/*   sched_time                                                              */
/*     scheduled time of the request                                         */
/*   exec_time                                                               */
/*     time when the request was executed                                    */
/*   unsolicited                                                             */
/*     Meaningful only for reports, not used for requests.                   */
/*     TRUE  - this report is unsolicited - i.e. it is in response to an     */
/*             Inventory Discovery request.                                  */
/*     FALSE - this report is solicited, i.e. it is a direct response to     */
/*             a request.                                                    */
/*     In R. 3 another meaning was added to this flag:                       */
/*        CM_INV_UNSOLICITED unsolicited report coming from inv req          */
/*        CM_CHKCM_UNSOLICITED unsolicited report coming from chkcm req      */
/*                                                                           */
/*   local_origin                                                            */
/*     Origin flag for request/report. This flag is TRUE if this request     */
/*     (or the request for which this is a report) was initiated by the UI   */
/*     on the local system OR this is a report sent to the local system for  */
/*     which the local system did not issue a request (an 'Unsolicited       */
/*     Report').                                                             */
/*     The flag is FALSE if this request (or the request for which this is a */
/*     report) was initiated by a remote node.                               */
/*   type                                                                    */
/*     D&CC request/response type - values listed below                      */
/*   flags                                                                   */
/*     RR flags. These are set to NULL (by the UI and NGA Out) when the      */
/*     request is created and set or reset throughout the lifetime of the    */
/*     request. Values are listed below                                      */
/*   originator                                                              */
/*     This is the name of the locally configured Target that issued this    */
/*     request (or the request for which this is the report).                */
/*   destination                                                             */
/*     This is the name of the locally configured Target to which this       */
/*     request (or the request for which this is the report) is to be sent.  */
/*   dest_conn                                                               */
/*     This is the name of the connection to be used to send the request.    */
/*     If dest_conn is set, the vector V_ADDRESS_LIST specifies the          */
/*     destination list; in this case destination is set to zeroes.          */
/*   global_name                                                             */
/*     global name(s) to be fetched/stored/deleted with this request/report  */
/*   filename                                                                */
/*     For uncatalogued requests/reports (flags is RR_SENDF, RR_RETRIEVEF,   */
/*     RR_EXECUTEF, RR_DELETEF) this field contains the name of the file the */
/*     request/report relates to.  If this field is set global_name is NOT   */
/*     set and vice versa.                                                   */
/*   source                                                                  */
/*     Local or remote node from which this request came (and to which       */
/*     reports - in particular, Fetch reports - go to).                      */
/*   history_reset                                                           */
/*     If this field is set to TRUE the CM status history for the destination*/
/*     target will be reset.                                                 */
/*   filler                                                                  */
/*     future use.                                                           */
/*                                                                           */
/*   The structure needs to be 4-byte aligned here - currently no pad needed */
/*                                                                           */
/*   type_data                                                               */
/*     Data specific to this D&CC type                                       */
/*   user                                                                    */
/*     Name of the user who issued the request                               */
/*   vector                                                                  */
/*     Optional and variable length data                                     */
/*     Type of data in this vector is one of the V_xxxx types of structures. */
/*     In RR_INFO there can only be a V_ADDRESS_LIST vector if dest_conn is  */
/*     NOT a blank name and is terminated by a V_LAST_VECTOR.                */
/*     V_ADDRESS_LIST contains the list of destination for the request (or   */
/*     the request for which this is the report)                             */
/*                                                                           */
/*****************************************************************************/
typedef struct rr_info
{
  REQUEST_ID        req_id;
  DC_CHAR           subreq_id[DVA_REQID_LEN];
  SCHEDULE_INFO     sched_info;
  DC_ULONG          seq_no;
  SCHED_TIME        submit_time;
  SCHED_TIME        sched_time;
  SCHED_TIME        exec_time;
  DC_USHORT         unsolicited;
  DC_USHORT         local_origin;
  DC_USHORT         type;
  DC_ULONG          flags;
  DC_CHAR           originator[DVA_TRGNAME_LEN];
  DC_CHAR           destination[DVA_TRGNAME_LEN];
  DC_CHAR           dest_conn[DVA_CONN_NM_LEN];
  DC_GLOB           global_name;
  DC_CHAR           filename[DVA_LOCNAME_LEN];
  DC_CHAR           source[DVA_TRGNAME_LEN];
  DC_USHORT         history_reset;
  DC_CHAR           filler[RR_INFO_FILLER_SIZE];
  GENERIC_RR        type_data;
  DC_CHAR           user[DVA_USRNAME_LEN];
  DC_CHAR           vector[4];
} RR_INFO;



/*****************************************************************************/
/* Structure: CX_USER_RESPONSE                                               */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure defines the format of the User-Exit response to the      */
/*   Notification of Request User-Exit.                                      */
/*                                                                           */
/* Fields:                                                                   */
/*   rc                                                                      */
/*     Result of cx_daca_request                                             */
/*   reserved                                                                */
/*     Dummy field for structure for future expansion.                       */
/*                                                                           */
/*****************************************************************************/
typedef struct cx_user_response
{
  DC_USHORT    rc;
  DC_USHORT    reserved;
} CX_USER_RESPONSE;



extern DC_VOID cx_daca_filename(DC_GLOB *globname,
                                DC_CHAR  locname[DVA_LOCNAME_LEN]);
/*****************************************************************************/
/*                                                                           */
/* Description: This routine receives the global name and the proposed local */
/*              name before a Distribution request executed by DACA.  It may */
/*              modify the contents of locname before returning.             */
/*                                                                           */
/*              This routine is called from 4 points in DFS                  */
/*              - cf_delete_rp before DELETE_REQ processing starts           */
/*              - cf_fetch_rp before FETCH_REQ processing starts             */
/*              - twice in cf_store_rp before STORE_REQ processing starts,   */
/*                once for the file to be stored and once for the file to be */
/*                deleted (if specified in the request)                      */
/*                                                                           */
/* Parameters:  globname - SNA/FS name of object to be stored at the Target  */
/*              locname  - proposed local name of the object                 */
/*                                                                           */
/* Returns:     Nothing                                                      */
/*                                                                           */
/*****************************************************************************/



extern DC_VOID cx_daca_report(RR_INFO *report_ptr);
/*****************************************************************************/
/*                                                                           */
/* Description: This routine receives the report DACA is about to send to    */
/*              the Server. It may modify the contents of the report before  */
/*              it is sent.                                                  */
/*                                                                           */
/*              This routine is called from a single point in DPS, the       */
/*              send_report routine.                                         */
/*                                                                           */
/* Parameters:  report - pointer to RR_INFO structure allocated ad hoc       */
/*                                                                           */
/* Returns:     Nothing                                                      */
/*                                                                           */
/*****************************************************************************/



extern DC_VOID cx_daca_request(RR_INFO      *request_ptr,
                               CX_USER_RESPONSE *puserrsp);
/*****************************************************************************/
/*                                                                           */
/* Description: This routine is called by DACA on receipt of a D&CC request  */
/*              from the Server.                                             */
/*                                                                           */
/*              This routine is called from a single point in DPS, the       */
/*              request_manager routine.                                     */
/*                                                                           */
/* Parameters:  request_ptr - pointer to RR_INFO structure                   */
/*              puserrsp - pointer to reponse structure returned             */
/*                                                                           */
/* Returns:     Nothing                                                      */
/*                                                                           */
/*****************************************************************************/


DC_VOID sx_server_report(RR_INFO *report_ptr);
/*****************************************************************************/
/*                                                                           */
/* Description: This routine receives a copy of the server report when the   */
/*              scheduler has already processed it. It can use the report    */
/*              contents to get statistical report or whatever the user can  */
/*              ask.                                                         */
/*                                                                           */
/*              This routine is called from a single point in the Scheduler  */
/*              manage_reports routine.                                      */
/*                                                                           */
/* Parameters:  report_ptr - pointer to RR_INFO structure containing a copy  */
/*                           of the report                                   */
/*                                                                           */
/* Returns:     Nothing                                                      */
/*                                                                           */
/*****************************************************************************/


DC_VOID sx_server_request(RR_INFO           *request_ptr,
                          CX_USER_RESPONSE  *puserrsp);
/*****************************************************************************/
/*                                                                           */
/* Description: This routine receives a copy of the server request when the  */
/*              scheduler is going to process it. It can use the request     */
/*              contents to get statistical report or whatever the user can  */
/*              ask.                                                         */
/*                                                                           */
/*              This routine is called from a single point in the Scheduler  */
/*              manage_requests routine.                                     */
/*                                                                           */
/* Parameters:  request_ptr - pointer to RR_INFO structure containing a      */
/*                            copy of the D&CC request from the server       */
/*              puserrsp    - pointer to user response structure             */
/*                                                                           */
/* Returns:     Nothing                                                      */
/*                                                                           */
/*****************************************************************************/

extern DC_SHORT cx_vercm( DC_CHAR  *cf_type,
                          DC_EXT_PRODUCT *product,
                          DC_EXT_FILESET *fileset,
                          DC_CHAR        *mask);
/*****************************************************************************/
/*                                                                           */
/* Description:                                                              */
/*  This function is called by the Netview DM/6000 agent to write into the   */
/*  fileset state field (see DVA_EXT_FILESET structure) the real status      */
/*  of the fileset in the target according to the relationship between       */
/*  the status of the fileset in a non-nvdm database and the change file     */
/*  CM status.                                                               */
/*                                                                           */
/* Parameters:                                                               */
/*     cf_type:  type of the change file                                     */
/*     product:  pointer to the product fields                               */
/*     fileset:  pointer to the fileset fields                               */
/*     mask   :  pointer to the mask used by agent to compare the            */
/*               fileset status with the change file status                  */
/*                                                                           */
/* Returns:     0                                                            */
/*              4  DB error                                                  */
/*             12  exit routine error                                        */
/*****************************************************************************/

/*****************************************************************************/
/* Values returned from User_Exits used to mount and unmount a File System   */
/*****************************************************************************/
#define MNT_OK           0
#define ALREADY_MOUNTED  4
#define MNT_ERROR        8

#define UMNT_OK          0
#define UMNT_NOT_FOUND   4
#define UMNT_ERROR       8


DC_USHORT cx_mount_fs   ( REMOTE_DIR    *remote_dir,
                          DC_VOID      **user_data,
                          DC_USHORT prot);
/*****************************************************************************/
/*                                                                           */
/* Description: This routine is called by the agent to mount a list of File  */
/*              Systems.                                                     */
/*              It is called before executing the request.                   */
/*                                                                           */
/* Parameters:                                                               */
/*              *remote_dir    : remote directory to be mounted              */
/*              **user_data    : user exit data. The same is passed          */
/*                               to the cx_unmount_fs user exit              */
/*              prot           : transport protocol (used on OS/2 platform)  */
/*                                       1 for TCP/IP                        */
/*                                       3 for NETBIOS                       */
/*                                       4 for IPX                           */
/*                                                                           */
/* Returns:     0   : File system successfully mounted.                      */
/*                    An informational message is logged.                    */
/*              4   : File System already mounted.                           */
/*                    An informational message is logged.                    */
/*              8   : An error was encountered mounting the File System.     */
/*                    An error message is logged and the Operating System    */
/*                    error_code is returned in the output parameter errcode.*/
/*                                                                           */
/*****************************************************************************/


DC_USHORT cx_unmount_fs   ( REMOTE_DIR    *remote_dir,
                            DC_VOID      **user_data,
                            DC_USHORT prot);
/*****************************************************************************/
/*                                                                           */
/* Description: This User-Exit is called by the agent to unmount a list of   */
/*              File System.                                                 */
/*              It is called at completion of the request.                   */
/*                                                                           */
/* Parameters:                                                               */
/*              *remote_dir    : remote directory to be unmounted            */
/*              **user_data    : user exit data. The same is passed          */
/*                               to the cx_unmount_fs user exit              */
/*              prot           : transport protocol (used on OS/2 platform)  */
/*                                       1 for TCP/IP                        */
/*                                       3 for NETBIOS                       */
/*                                       4 for IPX                           */
/*                                                                           */
/* Returns:     0   : File system successfully unmounted.                    */
/*                    An informational message is logged.                    */
/*              4   : File System to be unmounted not found.                 */
/*                    An error message is logged.                            */
/*              8   : An error was encountered unmounting the File System.   */
/*                    An error message is logged and the Operating System    */
/*                    error_code is returned in the output parameter errcode.*/
/*                                                                           */
/*****************************************************************************/

extern DC_VOID cx_set_secure_key( DC_ULONG  *crc_vector,
                                  DC_USHORT  number_of_crcs,
                                  DC_VOID   *secure_key,
                                  DC_USHORT  secure_key_len);
/*****************************************************************************/
/*                                                                           */
/* Description:                                                              */
/*  This function is called by the Netview DM/6000 user interface in order   */
/*  to calculate, using a user-defined algorithm, the secure key associated  */
/*  with a Change File.                                                      */
/*                                                                           */
/*                                                                           */
/* Parameters:                                                               */
/*     crc_vector:     pointer to the array containing the CRCs associated   */
/*                     with all the objects in the Change File.              */
/*                     (the CRC is 0 for the directories and for objects     */
/*                     to be deleted).                                       */
/*     number_of_crcs: number of elements in the vector.                     */
/*     secure_key:     buffer containing the calculated secure key to be     */
/*                     verified at installation time (to be returned).       */
/*                     Netview DM/6000 assumes that if all the bytes         */
/*                     are equal to '\0', the buffer is empty                */
/*                     and no secure key will be associated with the change  */
/*                     file. This is the default.                            */
/*                                                                           */
/*     secure_key_len: length of the secure key (equal to 32 bytes).         */
/*                                                                           */
/* Returns:     None                                                         */
/*****************************************************************************/

extern DC_VOID cx_check_secure_key( DC_VOID   *secure_key,
                                    DC_USHORT  secure_key_len,
                                    DC_USHORT *action);
/*****************************************************************************/
/*                                                                           */
/* Description:                                                              */
/*  This function is called by the Netview DM/6000 agent to allow at install */
/*  time checks on the secure key contained in the change file and set by    */
/*  the cx_set_secure_key at preparation time.                               */
/*                                                                           */
/*                                                                           */
/* Parameters:                                                               */
/*     secure_key:     buffer containing the secure key to be verified.      */
/*     secure_key_len: length of the secure key (equal to 32 bytes).         */
/*     action:   Allowed values are:                                         */
/*                 - CM_INSTALLABLE                                          */
/*                         This is the default. If this value is returned,   */
/*                         the agent continue the installation.              */
/*                 - CM_NO_INSTALLABLE                                       */
/*                         If this value is returned, the agent ends the     */
/*                         installation of the change file reporting a       */
/*                         failure.                                          */
/*                                                                           */
/* Returns:     None                                                         */
/*****************************************************************************/

extern DC_VOID cx_check_crcs( DC_ULONG  *crc_vector,
                              DC_USHORT  number_of_crcs,
                              DC_VOID   *secure_key,
                              DC_USHORT  secure_key_len,
                              DC_USHORT *action);
/*****************************************************************************/
/*                                                                           */
/* Description:                                                              */
/*  This function is called at install time by the Netview DM/6000 agent to  */
/*  recalculate, using a user-defined algorithm, the secure key based on the */
/*  provided list of crc, and compare it with the secure key calculated at   */
/*  preparation time.                                                        */
/*                                                                           */
/*                                                                           */
/* Parameters:                                                               */
/*     crc_vector:     pointer to the array containing the CRCs associated   */
/*                     with all the objects in the Change File.              */
/*                     (the CRC is 0 for the directories and for objects     */
/*                     to be deleted).                                       */
/*     number_of_crcs: number of elements in the vector.                     */
/*     secure_key:     buffer containing the calculated secure key to be     */
/*                     verified at installation time                         */
/*     secure_key_len: length of the secure key (equal to 32 bytes).         */
/*     action:   Allowed values are:                                         */
/*                 - CM_INSTALLABLE                                          */
/*                         This is the default. Continue the installation    */
/*                 - CM_NO_INSTALLABLE                                       */
/*                         If this value is returned, it means that the      */
/*                         comparison between the secure key calculated at   */
/*                         preparation time, and the secure key calculated   */
/*                         at install time was not successful.               */
/*                         In this case NetView DM/6000 agent ends the       */
/*                         installation reporting a failure.                 */
/*                                                                           */
/* Returns:     None                                                         */
/*****************************************************************************/

#define CM_INSTALLABLE                 0
#define CM_NO_INSTALLABLE              1

/* fndcx.h */
#endif
