#ifndef __fndhdr_h
#define __fndhdr_h
/*****************************************************************************/
/*                                                                           */
/*    COPYRIGHT : 5765 - 196                                                 */
/*    (C) COPYRIGHT IBM CORP 1993                                            */
/*    ALL RIGHTS RESERVED                                                    */
/*    LICENSED MATERIALS - PROPERTY OF IBM                                   */
/*                                                                           */
/* Product:         NetView Distribution Manager/6000                        */
/*                                                                           */
/* Module:          FNDHDR.H                                                 */
/*                                                                           */
/* Description:     Header defining the Common Types and Macros              */
/*                                                                           */
/* Overview:        This routine is included as the first include file       */
/*                  in all compilation units.                                */
/*                                                                           */
/* $C1=def12170 NWdev3270 28/07/99 AC : New build environment Watcom11b		 */
/*****************************************************************************/

#if defined(DVN_ENV)
/*****************************************************************************/
/* Turn off "Label 'dva_exit' has been defined but not referenced" compiler  */
/* warning (which otherwise floods the compiler's output)                    */
/*****************************************************************************/
#pragma disable_message(118)
#endif

#include <stdlib.h>
#include <time.h>

#if defined(DVA_IRIX)
#include <sys/bsd_types.h>
#include <sys/types.h>
#if !defined(__WIDEC_H__)
#include <widec.h>
#if !defined(WINT_T)
#define WINT_T
typedef wchar_t wint_t;
#endif /* WINT_T */
#define wcslen(x)       wslen( (x) )
#endif  /* WIDEC.H */

#elif !defined(DVN_ENV) /* not IRIX */ /*$C1 C*/ 
#include <wchar.h>
#endif

/*****************************************************************************/
/* Common Simple Types                                                       */
/*****************************************************************************/
#if defined (NVDMGI) || defined (DVA_SCO)
  #define DC_CHAR   char
#else
  #define DC_CHAR   unsigned char
#endif
#define DC_SHORT    short
#define DC_USHORT   unsigned short
#define DC_LONG     long
#define DC_ULONG    unsigned long
#define DC_TIME_T   time_t
#define DC_VOID     void
#define DC_OK       0
#define DC_NULL
#if defined(NVDMGI)
#if defined(DVW_ENV) || defined(DVO_ENV)
#define DC_UCHAR    unsigned char
#else
#define DC_UCHAR    DC_CHAR
#endif
#else
#define DC_UCHAR    DC_CHAR
#endif
/*****************************************************************************/
/*                                                                           */
/* Length of a Target Name                                                   */
/*                                                                           */
/* Defines the maximum number of bytes that may comprise a DIVA Target name. */
/* This limit ties in with the TCP/IP limit on workstation names.            */
/*                                                                           */
/* AIX has an internal limit of 32 characters so this will normally be       */
/* half empty                                                                */
/*                                                                           */
/* All Target names must be null-terminated, so the effective limit is one   */
/* less than DVA_TRGNAME_LEN.                                                */
/*****************************************************************************/
#define DVA_TRGNAME_LEN   64

/*****************************************************************************/
/* Type: TARGET_NAME                                                         */
/*                                                                           */
/* Overview:                                                                 */
/*   This type is used to hold target names                                  */
/*   Each is at most DVA_TRGNAME_LEN - 1 chars long, followed by a null.     */
/*                                                                           */
/*****************************************************************************/
typedef  char  TARGET_NAME[DVA_TRGNAME_LEN];

/*****************************************************************************/
/*                                                                           */
/* Length of a Machine Type                                                  */
/*                                                                           */
/* The effective maximum length of a machine type is 5 chars (HP_UX),        */
/* followed by a null.                                                       */
/*****************************************************************************/
#define DVA_MACHTYPE_LEN   16

/*****************************************************************************/
/*                                                                           */
/* Length of each component of a Global Name                                 */
/*                                                                           */
/*****************************************************************************/
#define DVA_GN_COMP_LEN   16

/*****************************************************************************/
/*                                                                           */
/* Number of components in a Global Name                                     */
/*                                                                           */
/*****************************************************************************/
#define DVA_NUM_GN_COMP   10

/*****************************************************************************/
/*                                                                           */
/* Maximum and minimum numbers of tokens in a Change File component name     */
/*                                                                           */
/*****************************************************************************/
#define DVA_MAX_COMP_TOK  7
#define DVA_MIN_COMP_TOK  1

/*****************************************************************************/
/*                                                                           */
/* Maximum length for a Global Name                                          */
/*                                                                           */
/*****************************************************************************/
#define DVA_GLOB_LEN   65

/*****************************************************************************/
/*                                                                           */
/* Constant for token field in a DC_GLOB indicating end-of-tokens.           */
/*                                                                           */
/*****************************************************************************/
#if defined (DVA_HPUX) || defined (SUN_CLIENT) || \
    defined (NCR_CLIENT) || defined (DVA_SCO)
#  define DVA_END_TKN    ((DC_CHAR)0xFF)
#else
#  define DVA_END_TKN    0xFF
#endif

/*****************************************************************************/
/*                                                                           */
/* Constant for token field in a DC_GLOB indicating token-not-specified.     */
/*                                                                           */
/*****************************************************************************/
#if defined (DVA_HPUX) || defined (SUN_CLIENT) || \
    defined (NCR_CLIENT) || defined (DVA_SCO)
#  define DVA_NO_TKN    ((DC_CHAR)0xFE)
#else
#  define DVA_NO_TKN     0xFE
#endif

/*****************************************************************************/
/*                                                                           */
/* Internal structure of a Global Name used by DIVA                          */
/*                                                                           */
/* tokens is an array of offsets into name, giving the start of each         */
/* token in the name. All entries beyond the last token in name are set to   */
/* DVA_END_TKN.                                                              */
/*                                                                           */
/* name is a Global Name with the token separators replaced by nulls: the    */
/* tokens appear in the order in which they occur in the Global Name and     */
/* are separated by exactly one null. All characters beyond the end of the   */
/* last token are set to null.                                               */
/*                                                                           */
/* These rules ensure a unique representation for each Global Name; thus     */
/* memcmp() may be used to compare Global Names with each other.             */
/*                                                                           */
/* Examples: token[0] = 0 always. The third token of glob_name is the string */
/* starting at glob_name.name[tokens[2]]. If glob_name consists of 10        */
/* tokens, token[10] = DVA_END_TKN.                                          */
/*                                                                           */
/* Missing tokens: Note that if the nth token is missing from the name, its  */
/* .tokens entry is set to DVA_NO_TKN. No null separator is encoded for the  */
/* token in the .name array. This value is used internally in FS and should  */
/* never be passed to or used by the UI or DAS.  Such missing tokens are     */
/* valid only in partially specified names received from the host.           */
/*                                                                           */
/* Note: if DVA_NUM_GN_COMP or DVA_GLOB_LEN change, this structure must be   */
/* adjusted to end on a DWORD boundary.                                      */
/*****************************************************************************/
typedef struct dc_glob
{
  DC_CHAR   tokens[DVA_NUM_GN_COMP + 1];
  DC_CHAR   name [DVA_GLOB_LEN];
} DC_GLOB;


/*****************************************************************************/
/* Maximum number of different client type supported                         */
/*****************************************************************************/
#define DVA_LOCAL_NAME_CNT       8

/*****************************************************************************/
/*                                                                           */
/* Length of a Local File Name                                               */
/*                                                                           */
/* This limit limits the length of a local file name supported by DIVA.      */
/* This is a compromise between the flexibility gained by long names, and    */
/* the excessive UNIX limit of 1024 bytes. (Which would take an average      */
/* person five minutes to type!)                                             */
/*                                                                           */
/* The effective maximum length of a local filename is 255 bytes, followed   */
/* by a null.                                                                */
/*****************************************************************************/
#define DVA_LOCNAME_LEN   256

/*****************************************************************************/
/* Type: DC_FILE_NAME                                                        */
/*                                                                           */
/* Overview:                                                                 */
/*   This type is used to hold local file names                              */
/*   Each is at most DVA_LOCNAME_LEN - 1 chars long, followed by a null.     */
/*                                                                           */
/*****************************************************************************/
typedef DC_CHAR DC_FILE_NAME[DVA_LOCNAME_LEN];

/*****************************************************************************/
/* Structure: DC_DATA_NAME                                                   */
/*                                                                           */
/* Fields:                                                                   */
/*   name_len                                                                */
/*     length of the local file name in the other field                      */
/*   file_name                                                               */
/*     local file name in a fixed length buffer right padded with chr(0)     */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure contains a local file name and the length of the name.   */
/*                                                                           */
/*****************************************************************************/

typedef struct dc_data_name
{
  DC_USHORT       name_len;
  DC_CHAR         pad[2];
  DC_FILE_NAME    file_name;
} DC_DATA_NAME;


/*****************************************************************************/
/* Structure: DVA_DATE                                                       */
/*                                                                           */
/* Fields:                                                                   */
/*   year                                                                    */
/*     Year of scheduled time (4 digits, eg. 1993)                           */
/*   month                                                                   */
/*     Month of specified time (1 - 12).                                     */
/*   day                                                                     */
/*     Day of specified time (1 - 31).                                       */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used to hold a date value.                            */
/*****************************************************************************/
typedef struct dva_date
{
  DC_USHORT    year;
  DC_CHAR      month;
  DC_CHAR      day;
} DVA_DATE;


/*****************************************************************************/
/* Structure: DVA_TIME                                                       */
/*                                                                           */
/* Fields:                                                                   */
/*   hour                                                                    */
/*     Hour of specified time (0 - 23).                                      */
/*   minute                                                                  */
/*     Minute of specified time (0 - 59).                                    */
/*   second                                                                  */
/*     Second of specified time (0 - 59).                                    */
/*   gmt                                                                     */
/*     Indicator specifying whether this time is in local or GMT format. All */
/*     times generated by the Scheduler and UI will be in local format       */
/*     (RR_LOCAL_TIME).  Values listed below.                                */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used to hold a time of day value.                     */
/*****************************************************************************/
typedef struct dva_time
{
  DC_CHAR      hour;
  DC_CHAR      minute;
  DC_CHAR      second;
  DC_CHAR      gmt;
} DVA_TIME;

/*****************************************************************************/
/* Values for GMT indicator                                                  */
/*****************************************************************************/
#define   RR_LOCAL_TIME   0
#define   RR_GMT_TIME     1

/*****************************************************************************/
/* Structure: DVA_DATE_TIME                                                  */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used to specify times in a format independent of      */
/*   changes to or from daylight savings time                                */
/*                                                                           */
/* Fields:                                                                   */
/*   date                                                                    */
/*     The date.                                                             */
/*   time                                                                    */
/*     The time of day.                                                      */
/*****************************************************************************/
typedef struct dva_date_time
{
  DVA_DATE     date;
  DVA_TIME     time;
} DVA_DATE_TIME;

/*****************************************************************************/
/* Macros to set Date & Time NEVER_END values                                */
/*****************************************************************************/
#define   DVA_DATE_NEVER_END(year)                                            \
                             year = 0xffff;

/*****************************************************************************/
/* Macros to test Date & Time NEVER_END values                               */
/* Return TRUE if the Date or the Time NEVER_ENDS, FALSE otherwise           */
/*****************************************************************************/
#define   DVA_DATE_NEVER_ENDS( _date )                                        \
             ( (_date).year == 0xffff )

#define   DVA_DATIME_NEVER_ENDS( _datime )                                    \
             DVA_DATE_NEVER_ENDS( (_datime).date )

/*****************************************************************************/
/* Values for the very first and the very last time of a day.                */
/*****************************************************************************/


#ifdef DVA_TIME_EXT
/* ------------------------- Define & Initialize begin ------ */

/* ****************************************************************** */
/* Patch for C++ compiler behaviour in Sinix                          */
/* Extern Initalization (!!) needed to export the symbol              */
/* ****************************************************************** */
#if defined(DVA_UNIX) && defined(NVDMGI)
extern const DVA_TIME DVA_TIME_FIRST = {  0,  0,  0, 0 } ;
extern const DVA_TIME DVA_TIME_LAST  = { 23, 59, 59, 0 } ;
#else
const  DVA_TIME     DVA_TIME_FIRST = {  0,  0,  0, 0 } ;
const  DVA_TIME     DVA_TIME_LAST  = { 23, 59, 59, 0 } ;
#endif

/* ------------------------- Define & Initialize end   ------ */
#else
extern const  DVA_TIME     DVA_TIME_FIRST  ;
extern const  DVA_TIME     DVA_TIME_LAST   ;
#endif

/*****************************************************************************/
/* Constant values for days in the week                                      */
/*****************************************************************************/
#define   DVA_WEEK_DAY1   0x80
#define   DVA_WEEK_DAY2   0x40
#define   DVA_WEEK_DAY3   0x20
#define   DVA_WEEK_DAY4   0x10
#define   DVA_WEEK_DAY5   0x08
#define   DVA_WEEK_DAY6   0x04
#define   DVA_WEEK_DAY7   0x02

/*****************************************************************************/
/* Constant values for days in the month                                     */
/*****************************************************************************/
#define   DVA_MONTH_DAY1   0x80000000
#define   DVA_MONTH_DAY2   0x40000000
#define   DVA_MONTH_DAY3   0x20000000
#define   DVA_MONTH_DAY4   0x10000000
#define   DVA_MONTH_DAY5   0x08000000
#define   DVA_MONTH_DAY6   0x04000000
#define   DVA_MONTH_DAY7   0x02000000
#define   DVA_MONTH_DAY8   0x01000000
#define   DVA_MONTH_DAY9   0x00800000
#define   DVA_MONTH_DAY10  0x00400000
#define   DVA_MONTH_DAY11  0x00200000
#define   DVA_MONTH_DAY12  0x00100000
#define   DVA_MONTH_DAY13  0x00080000
#define   DVA_MONTH_DAY14  0x00040000
#define   DVA_MONTH_DAY15  0x00020000
#define   DVA_MONTH_DAY16  0x00010000
#define   DVA_MONTH_DAY17  0x00008000
#define   DVA_MONTH_DAY18  0x00004000
#define   DVA_MONTH_DAY19  0x00002000
#define   DVA_MONTH_DAY20  0x00001000
#define   DVA_MONTH_DAY21  0x00000800
#define   DVA_MONTH_DAY22  0x00000400
#define   DVA_MONTH_DAY23  0x00000200
#define   DVA_MONTH_DAY24  0x00000100
#define   DVA_MONTH_DAY25  0x00000080
#define   DVA_MONTH_DAY26  0x00000040
#define   DVA_MONTH_DAY27  0x00000020
#define   DVA_MONTH_DAY28  0x00000010
#define   DVA_MONTH_DAY29  0x00000008
#define   DVA_MONTH_DAY30  0x00000004
#define   DVA_MONTH_DAY31  0x00000002

/*****************************************************************************/
/* Error level return codes                                                  */
/*****************************************************************************/
#define    DVA_RC_LEVEL_OK        0
#define    DVA_RC_LEVEL_WRN       4
#define    DVA_RC_LEVEL_ERR       8
#define    DVA_RC_LEVEL_SEV       12
#define    DVA_RC_LEVEL_UNR       16

/*****************************************************************************/
/* Structure: DC_UFID                                                        */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure defines the UFID                                         */
/*                                                                           */
/* Fields:                                                                   */
/*   ufid_file_id                                                            */
/*     the part of the UFID that identifies the unique file                  */
/*   ufid_instance                                                           */
/*     an instance count to distinguish different incarnations of the file   */
/*   ufid_use_id                                                             */
/*     identifies a use of the UFID by another object                        */
/*                                                                           */
/*****************************************************************************/
typedef struct dc_ufid
{
  DC_ULONG    ufid_file_id;
  DC_ULONG    ufid_instance;
  DC_ULONG    ufid_use_id;
} DC_UFID;

/*****************************************************************************/
/* intended global name usages                                               */
/* Use in status fields of DC_NAMES structure                                */
/*****************************************************************************/
#define DC_NAME_TO_USE            1     /* future tense                      */
#define DC_NAME_USED              2     /* past tense success                */
#define DC_NAME_FAILED            3     /* past tense failure                */
#define DC_NAME_ABSENT            4     /* this name not present             */

/*****************************************************************************/
/* ... dt_flags  #define values                                              */
/*                                                                           */
/* These vaues are set by SS when it receives a global file name which       */
/* matches a catalog entry containing &DATE and /or &TIME. They are used by  */
/* DACA in matching or seting against the local file name on the destination */
/* client system                                                             */
/*                                                                           */
/* Note that  (i) the Match flags and Set flags are exclusive                */
/*            (ii) only one of the ...dt_flags fields can have a value set - */
/*                 all others are 0.                                         */
/*                                                                           */
/*****************************************************************************/
#define DC_MATCH_DATE          0x01     /* match date value supplied to file */
#define DC_MATCH_TIME          0x02     /* match time value supplied to file */
#define DC_SET_DATE            0x04     /* set date of file to value         */
                                        /* supplied                          */
#define DC_SET_TIME            0x08     /* set time of file to value         */
                                        /* supplied                          */
#define DC_GET_DATE            0x10     /* get date of file and return in    */
                                        /* report                            */
#define DC_GET_TIME            0x20     /* get time of file and return in    */
                                        /* report                            */


/*****************************************************************************/
/* del_uncat actions                                                         */
/* Use in del_uncat field of DC_NAMES structure                              */
/*****************************************************************************/
#define DC_DONT_UNCAT             0     /* must not uncatalog                */
#define DC_TRY_UNCAT              1     /* may attempt uncatalog             */

/*****************************************************************************/
/* fixed_len_fmt flags                                                       */
/* Use in fixed_len_fmt flag of DC_NAMES structure                           */
/*****************************************************************************/
#define DC_NOT_FIXED              0     /* not a fixed length record format  */
#define DC_FIXED_FMT              1     /* data file is fixed_len format     */

/*****************************************************************************/
/* Structure: DC_NAMES                                                       */
/*                                                                           */
/* Fields:                                                                   */
/*   data_ufid                                                               */
/*     ufid of local file name. THIS FIELD MUST NOT BE MOVED FROM THE FRONT  */
/*     OF THIS STRUCTURE (Scheduler Recoverability).                         */
/*   int_source_ufid                                                         */
/*     ufid of the temporary file at the intermediate source server,         */
/*     needed to support STS file transfer                                   */
/*     This ufid is at a remote server so it cannot be manipulated           */
/*     directly.  The name of the remote server where the ufid resides       */
/*     is given by the int_source field in QUEUE_ENTRY.                      */
/*   fixed_len_fmt                                                           */
/*     flag if a text file was received in fixed length record format        */
/*   del_uncat                                                               */
/*     flag how a DELETE request should handle the uncatalog of the GFN      */
/*   data_file                                                               */
/*     local name for data file. THIS FIELD MUST NOT BE MOVED FROM THE FRONT */
/*     OF THIS STRUCTURE (Scheduler Recoverability).                         */
/*   int_source_file                                                         */
/*     name of the temporary file at the intermediate source server          */
/*     corresponding to int_source_ufid above                                */
/*   uncat_file                                                              */
/*     local name for uncatalog file to be sent or retrieved. This is the    */
/*     file name as it is on the owner target.                               */
/*   fetch_n                                                                 */
/*     fetch(ed) name - name of file to be fetched or file that was fetched  */
/*     or of file that failed to be fetched. Meaning is governed by status   */
/*     field below.                                                          */
/*   fetch_stat                                                              */
/*     status of fetch name - indicate meaning of name in fetch_n field      */
/*   fetch_flags                                                             */
/*     SNA/FS matching flags to apply to name in fetch_n field               */
/*   store_n                                                                 */
/*     store(d) name - name of file to be stored or file that was stored     */
/*     or of file that failed to be stored. Meaning is governed by status    */
/*     field below.                                                          */
/*   store_stat                                                              */
/*     status of store name - indicate meaning of name in store_n field      */
/*   delete_n                                                                */
/*     delete(d) name - name of file to be deleted or file that was deleted  */
/*     or of file that failed to be deleted. Meaning is governed by status   */
/*     field below.                                                          */
/*   delete_stat                                                             */
/*     status of delete name - indicate meaning of name in delete_n field    */
/*   delete_flags                                                            */
/*     SNA/FS matching flags to apply to name in delete_n field              */
/*   rpt_on_name                                                             */
/*     reported-on name - name of file being reported on                     */
/*   fetch_dt_flags                                                          */
/*     Date/Time matching flags - MATCH values (or 0) only ever set          */
/*   store_dt_flags                                                          */
/*     Date/Time set flags - SET values (or 0) only ever set                 */
/*   delete_dt_flags                                                         */
/*     Date/Time match flags - MATCH values (or 0) only ever set             */
/*   sf_file_date                                                            */
/*     Date associated with Fetch/Store file for matching/setting            */
/*     Only set if fetch_dt_flags/store_dt_flags have value of DC_MATCH/SET_ */
/*     DATE                                                                  */
/*   sf_file_time                                                            */
/*     Time associated with Fetch/Store file for matching/setting            */
/*     Only set if fetch_dt_flags/store_dt_flags have value of DC_MATCH/SET_ */
/*     TIME                                                                  */
/*   del_file_date                                                           */
/*     Date associated with Delete file name for matching                    */
/*     Only set if delete_dt_flags have value of DC_MATCH_DATE               */
/*   del_file_time                                                           */
/*     Time associated with Delete file name for matching                    */
/*     Only set if delete_dt_flags have value of DC_MATCH_TIME               */
/*   reclen                                                                  */
/*     Record length for a text file (if not a text file, this field is      */
/*     undefined)                                                            */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure contains all of the information for received and sent    */
/*   Global File Names and local files. It maps to the SNA/FS Global Names   */
/*   subtable.                                                               */
/*                                                                           */
/*****************************************************************************/

typedef struct dc_names
{
  DC_UFID        data_ufid;
  DC_UFID        int_source_ufid;
  DC_CHAR        fixed_len_fmt;
  DC_CHAR        del_uncat;
  DC_DATA_NAME   data_file;
  DC_DATA_NAME   int_source_file;
  DC_DATA_NAME   uncat_file;
  DC_GLOB        fetch_n;
  DC_USHORT      fetch_stat;
  DC_CHAR        fetch_flags[DVA_NUM_GN_COMP];
  DC_GLOB        store_n;
  DC_USHORT      store_stat;
  DC_GLOB        delete_n;
  DC_USHORT      delete_stat;
  DC_CHAR        delete_flags[DVA_NUM_GN_COMP];
  DC_GLOB        rpt_on_name;
  DC_CHAR        fetch_dt_flags;
  DC_CHAR        store_dt_flags;
  DC_CHAR        delete_dt_flags;
  DC_CHAR        pad;
  DVA_DATE       sf_file_date;
  DVA_TIME       sf_file_time;
  DVA_DATE       del_file_date;
  DVA_TIME       del_file_time;
  DC_USHORT      reclen;
  DC_CHAR        pad2[2];
} DC_NAMES;

/*****************************************************************************/
/* Structure: DC_SSPARMS                                                     */
/*                                                                           */
/* Fields:                                                                   */
/*   svr_instr_except                                                        */
/*     this holds server instructions and exception actions encoded as       */
/*     specified in the SNA/FS Reference                                     */
/*   rptr_action                                                             */
/*     this holds the reporting action encoded as specified in the SNA/FS    */
/*     Reference                                                             */
/*   intention                                                               */
/*     this holds the intention operand as specified in the SNA/FS Reference */
/*   pad                                                                     */
/*     pad structure to four byte boundary                                   */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure contains Specific Server Parameters for encoding into    */
/*   Server Objects or as decoded from Server Objects                        */
/*                                                                           */
/*****************************************************************************/

typedef struct dc_ssparms
{
  DC_CHAR          svr_except;
  DC_CHAR          rpt_action;
  DC_CHAR          intention;
  DC_CHAR          pad;
} DC_SSPARMS;



/*****************************************************************************/
/*                                                                           */
/* Length of SNA/DS RGN and REN                                              */
/*                                                                           */
/* These values are used for the length of the RGN and REN components of a   */
/* SNA/DS RGN.REN name (a DSU name)                                          */
/*                                                                           */
/*****************************************************************************/
#define DVA_RGN_LEN  8
#define DVA_REN_LEN  8

/*****************************************************************************/
/*                                                                           */
/* Length of SNA/DS DGN and DEN                                              */
/*                                                                           */
/* These values are used for the length of the DGN and DEN components of a   */
/* SNA/DS DGN.DEN name (a user name)                                         */
/*                                                                           */
/*****************************************************************************/
#define DVA_DGN_LEN  8
#define DVA_DEN_LEN  8

/*****************************************************************************/
/*                                                                           */
/* Length of SNA/DS TP name                                                  */
/*                                                                           */
/* This value is used for the length of the Transaction Program names used   */
/* by SNA/DS.                                                                */
/*                                                                           */
/*****************************************************************************/
#define DVA_TPN_LEN  8

/*****************************************************************************/
/*                                                                           */
/* Length of SNA/DS lu alias and mode name                                   */
/*                                                                           */
/* These values are used for the length of the SNA/DS lu alias and mode name */
/* Length of symbolic destination name.                                      */
/*                                                                           */
/*****************************************************************************/
#define DVA_LU_LEN    17
#define DVA_MODE_LEN  8
#define DVA_SYM_DEST_LEN  9

/*****************************************************************************/
/*                                                                           */
/* Length of a connection name                                               */
/*                                                                           */
/*****************************************************************************/
#define DVA_CONN_NM_LEN     16

/*****************************************************************************/
/*                                                                           */
/* Length of a Configuration Name                                            */
/*                                                                           */
/* Defines the length of a Configuration Name. Configuration Names are:      */
/*                                                                           */
/*   Target Group Name                                                       */
/*   TSP Name                                                                */
/*   Functional Package Name                                                 */
/*   SNA/DS Group Name                                                       */
/*   Hardware Parameter Name                                                 */
/*                                                                           */
/* All these names must be null-terminated, so the effective limit is one    */
/* less than DVA_CFGNAME_LEN.                                                */
/*                                                                           */
/*****************************************************************************/
#define DVA_CFGNAME_LEN   81

/*****************************************************************************/
/* Maximum length (including NUL terminator) of parameter string which may   */
/* be passed to a command procedure invoked by an INITIATE_REQ               */
/*****************************************************************************/
#define DVA_IPARAMS_LEN   254

/*****************************************************************************/
/* Maximum number of co-requisite files which may be specified in Request    */
/* blocks.                                                                   */
/*****************************************************************************/
#define DVA_NUM_COREQS      6

/*****************************************************************************/
/* TRANSACTION PROGRAM NAME                                                  */
/*****************************************************************************/

typedef struct dc_tp_name {
    DC_USHORT   len;                    /* Length of name (1-8)              */
    DC_CHAR     pad[2];
    DC_CHAR     name[DVA_TPN_LEN];      /* TP Name (no ASCII translation)    */
} DC_TP_NAME;


/*****************************************************************************/
/* DSU RGN.REN NAME                                                          */
/*                                                                           */
/* Note. If a target rgn (or ren) is 8 character long, there is no room for  */
/*       the '\0' string-terminator character within DC_DSU_NAME structure.  */
/*       Therefore don't use strcpy, strcmp with rgn and ren.                */
/*       Use strcncpy, strncmp instead. You'll get less core dumps.          */
/*       For the same reason, use 8.8%s and not just %s as format string     */
/*       when using the TRACEx macros.                                       */
/*****************************************************************************/

typedef struct dc_dsu_name {
    DC_CHAR         rgn[DVA_RGN_LEN];   /* ASCII strings, A-Z and 0-9 only   */
    DC_CHAR         ren[DVA_REN_LEN];   /* padded with zero bytes            */
} DC_DSU_NAME;

/*****************************************************************************/
/* USER DGN.DEN NAME                                                         */
/*****************************************************************************/

typedef struct dc_user_name {
    DC_CHAR         dgn[DVA_DGN_LEN];   /* ASCII strings, exhanced char set  */
    DC_CHAR         den[DVA_DEN_LEN];   /* padded with zero bytes            */
} DC_USER_NAME;



/*****************************************************************************/
/* Structure: DC_SERVICE_PARMS                                               */
/*                                                                           */
/* Fields:                                                                   */
/*   priority                                                                */
/*     Priority service parameter                                            */
/*   protection                                                              */
/*     Protection service parameter                                          */
/*   capacity                                                                */
/*     Capacity service parameter                                            */
/*   security                                                                */
/*     Security service parameter                                            */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure contains the service parameters for a SNA/DS             */
/*   distribution.                                                           */
/*                                                                           */
/*****************************************************************************/
typedef struct dc_service_parms {
  DC_CHAR         priority;
  DC_CHAR         protection;
  DC_CHAR         capacity;
  DC_CHAR         security;
} DC_SERVICE_PARMS;

/*****************************************************************************/
/* Request identifier length                                                 */
/*****************************************************************************/
#define DVA_REQID_LEN         16

/*****************************************************************************/
/* Structure: DC_QUEUE_STATUS                                                */
/*                                                                           */
/* Fields:                                                                   */
/*   format                                                                  */
/*     Describes the format of the data in the queue entry following this    */
/*     structure. Values are listed below and depend on the structure        */
/*     (TC_SECURE_LIST or QUEUE_ENTRY) that has included this structure.     */
/*   component                                                               */
/*     Describes the component within NG who is responsible for processing   */
/*     this queue entry. Values are listed below. If the queue is outside    */
/*     NG, this field is set to DVA_Q_FOR_OTHER.                             */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is included at the head of TC and Scheduler format queue */
/*   entries. It tells the queue server what format to expect the following  */
/*   data in, and, for entries on the Secure List, which component of NG is  */
/*   responsible for processing this request.                                */
/*                                                                           */
/*****************************************************************************/
typedef struct dc_queue_status {
  DC_USHORT     format;
  DC_USHORT     component;
} DC_QUEUE_STATUS;

/*****************************************************************************/
/* Values for .format field                                                  */
/*****************************************************************************/
#define DVA_Q_TYPE_CH   0           /* Scheduler format entry (QUEUE_ENTRY)  */
#define DVA_Q_TYPE_TC   1           /* TC format entry (TC_SECURE_LIST)      */


/*****************************************************************************/
/* Values of .component field                                                */
/*****************************************************************************/
#define     DVA_Q_FOR_ROUTER    0
#define     DVA_Q_FOR_TRCV      1
#define     DVA_Q_FOR_TSND      2
#define     DVA_Q_FOR_NGAOUT    3
#define     DVA_Q_FOR_OTHER     4


/*****************************************************************************/
/* Transmission controller system limits                                     */
/*****************************************************************************/
#define     TC_MAX_PRTY         18      /* number of transmission priorities */
                                        /* (DATA_1 - 16, CONTROL, FAST)      */
#define     TC_MAX_CONNS        800     /* maximum number of                 */
                                        /* connections                       */
#define     TC_CONN_MAX_CONV    10      /* maximum number of conversations   */
                                        /* on any connection                 */
#define     TC_MAX_CONV         (TC_MAX_CONNS * TC_CONN_MAX_CONV * 2)
                                        /* total number of conversations     */
                                        /* in the system (includes direction)*/
#if defined(NVDMMOBCLNT)
#define     TC_MAX_ACTIVE_CONV    0
#else
#define     TC_MAX_ACTIVE_CONV  100     /* maximum number of                 */
                                        /* conversations active at any time  */
#endif
#define     TC_DIST_PER_CONN    20      /* nominal limit on the number of    */
                                        /* distributions which can be        */
                                        /* queued for a connection. This     */
                                        /* limit is not imposed but is used  */
                                        /* to determine the TOTAL queuing    */
                                        /* space available for all           */
                                        /* connections.                      */

#define     TC_MU_ID_RANGE     255     /* size of next-expected MU_ID range  */
                                       /* (allowed MU_IDs are from lowest    */
                                       /* NOT_RECEIVED to lowest             */
                                       /* NOT_RECEIVED + TC_MU_ID_RANGE,     */
                                       /* inclusive)                         */


/*****************************************************************************/
/* Structure: NG_WORK_SPACE                                                  */
/*                                                                           */
/* Fields:                                                                   */
/*   status                                                                  */
/*     Status of item of work within NGA. Values are listed below. This      */
/*     field must be reset to NGA_Q_NEW_ENTRY when is Transferred with       */
/*     Update to a NEW secure queue.                                         */
/*   disp_handle                                                             */
/*     Ufid handle for DISP=DELETE processing. This is the ufid handle       */
/*     assigned to the file to be deleted when all install/initiate          */
/*     processing has been completed, if DISP=DELETE is set in the current   */
/*     request. Otherwise this may be used for dummy handle accessed by      */
/*     disp=delete processing but withiout causing any file deletion.        */
/*   agent                                                                   */
/*     Ufid handle of the Agent Object on disk.  Depending on the value of   */
/*     .status, this is either the Input Agent Object to be deleted before   */
/*     passing this item of work on to the next component, or the Output     */
/*     Agent Object being created by NGA. If no Agent Object is to be        */
/*     deleted (or created), this field is set to DVA_UFID_UNDEF.            */
/*   server                                                                  */
/*     Ufid handle of the Server Object on disk. This is used in a similar   */
/*     manner to the .agent field above.                                     */
/*   data_uhandle                                                            */
/*     Ufid handle of the data file associated with the Server Object.       */
/*     This is used in conjunction with the .server field above.             */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure defines the format of the structure at the head of TC    */
/*   and Scheduler format queue entries.  By checking the .status field in   */
/*   this structure, NGA can determine whether the data that follows it is   */
/*   in TC Secure List format (TC_SECURE_LIST) or Scheduler format           */
/*   (QUEUE_ENTRY).  For all other components, the data that follows depends */
/*   on the component.                                                       */
/*                                                                           */
/*****************************************************************************/
typedef struct ng_work_space
{
  DC_USHORT    status;
  DC_UFID      disp_handle;
  DC_UFID      agent;
  DC_UFID      server;
  DC_UFID      data_uhandle;
} NG_WORK_SPACE;


/*****************************************************************************/
/* Values for NGA queue entry status                                         */
/*****************************************************************************/
#define     NGA_Q_NEW_ENTRY     0
#define     NGA_Q_GOT_ENTRY     1
#define     NGA_Q_REMOVE        2
#define     NGA_Q_TRANS_CH      3
#define     NGA_Q_TRANS_TC      4


/*****************************************************************************/
/* Structure: DC_USER_COMPRESS                                               */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used to hold user compression information             */
/*                                                                           */
/* Fields:                                                                   */
/*   algorithm_name                                                          */
/*     name of the user algorithm                                            */
/*   algorithm_parms                                                         */
/*     algortihm parameters                                                  */
/*   ccsid                                                                   */
/*     coded character set identifier                                        */
/*                                                                           */
/*****************************************************************************/

#define DVA_UC_NAME_LEN    13
#define DVA_UC_PARMS_LEN   28

typedef struct dc_user_compress
{
  DC_CHAR      algorithm_name[DVA_UC_NAME_LEN];
  DC_CHAR      algorithm_parms[DVA_UC_PARMS_LEN];
  DC_CHAR      pad1;
  DC_USHORT    ccsid;
} DC_USER_COMPRESS;

/*****************************************************************************/
/* Structure: DC_SNA_COMPRESS                                                */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used to hold SNA compression information              */
/*                                                                           */
/* Fields:                                                                   */
/*   prime_char                                                              */
/*     prime character                                                       */
/*                                                                           */
/*****************************************************************************/
typedef struct dc_sna_compress
{
  DC_CHAR      prime_char;
} DC_SNA_COMPRESS;

/*****************************************************************************/
/* Union: DC_COMPRESS                                                        */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used to hold compression instructions as stored in    */
/*   the Catalog.                                                            */
/*                                                                           */
/* Fields:                                                                   */
/*   comp_type                                                               */
/*     compression type, values listed below                                 */
/*   init_string                                                             */
/*     used to initialise the union                                          */
/*   user_compress                                                           */
/*     user compression algorithms                                           */
/*   sna_compress                                                            */
/*     SNA compression algorithms                                            */
/*                                                                           */
/*****************************************************************************/

#define DVA_COMP_INIT_LEN   44

typedef struct dc_compress
{
  DC_CHAR   comp_type;
  DC_CHAR   pad[3];
  union
  {
    DC_CHAR            init_string[DVA_COMP_INIT_LEN];
    DC_USER_COMPRESS   user_compress;
    DC_SNA_COMPRESS    sna_compress;
  } comp_data;
} DC_COMPRESS;

/*****************************************************************************/
/* Values for comp_type                                                      */
/*****************************************************************************/

#define NO_COMPRESS    0    /* file not compressed                           */
#define COMPRESS_SNA   1    /* file compressed by SNA Algorithm              */
#define COMPRESS_USER  2    /* file compressed by user algorithm             */
#define COMPRESS_ADAPT 3    /* file compressed by adaptive compression       */

/*****************************************************************************/
/* NVDMLZW user compression name definition - note this is the default       */
/* compression algorithmn.                                                   */
/*****************************************************************************/
#define COMPRESS_LZW   "NVDMLZW"

/*****************************************************************************/
/*                                                                           */
/* Length of a User Name                                                     */
/*                                                                           */
/* Defines the maximum number of bytes that may comprise a DIVA user name.   */
/*                                                                           */
/*****************************************************************************/
#define DVA_USRNAME_LEN   16

/*****************************************************************************/
/* Length of a User Name supplied on UI, inclusive end of the string.        */
/*****************************************************************************/
#define DVA_USRNAME2_LEN   9

/*****************************************************************************/
/* Minimum length of a User Name supplied on UI.                             */
/*****************************************************************************/
#define DVA_MINPWD_LEN     6

/*****************************************************************************/
/* Declares moved from fndcotyp.h - start                                    */
/*****************************************************************************/

/*****************************************************************************/
/*                                                                           */
/* Length of the language id descriptor in the catalog                       */
/*                                                                           */
/*****************************************************************************/
#define DVA_CAT_LANG_LEN      4

/*****************************************************************************/
/*                                                                           */
/* Length of a Description Field                                             */
/*                                                                           */
/* Used in Database File: DB_TARGET_CONFIG, DB_SNADS_GROUP, DB_SNADS_CONTROL */
/*                                                                           */
/* All descriptions in DIVA have the same length, and are null-terminated.   */
/* UI will not permit this length to be exceeded.                            */
/*                                                                           */
/*****************************************************************************/
#define DVA_DESCR_LEN     60

/*****************************************************************************/
/* Declares moved from fndcotyp.h - end                                      */
/*****************************************************************************/

/*****************************************************************************/
/* Structures moved from dvadbcat.h - start                                  */
/*****************************************************************************/

/*****************************************************************************/
/* Structure: CAT_ENTRY and SHORT_CAT_ENTRY                                  */
/*                                                                           */
/* Key:                                                                      */
/*   file (first field)                                                      */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure defines a Distribution Catalog record in the DIVA        */
/*   database.  The database identifier is DB_DISTRIB_CAT.                   */
/*                                                                           */
/*   Part of each record is cached in DAS memory; this part is much quicker  */
/*   to access than the rest of the record.  The structure SHORT_CAT_ENTRY   */
/*   defines the structure of this portion of the record.  The macro         */
/*   CAT_INFO_LEN defines the length of the cached part of each record.      */
/*                                                                           */
/*   Applications using the catalog should ensure that when they read an     */
/*   entry, the length read is <= CAT_INFO_LEN wherever possible.            */
/*                                                                           */
/*   NOTE: any changes to the first few fields here MUST be mirrored to      */
/*   INT_CAT_ENTRY in dvadb.h.  They must also be made to both structures    */
/*   (CAT_ENTRY and SHORT_CAT_ENTRY).                                        */
/*                                                                           */
/* Fields:                                                                   */
/*   glob_name                                                               */
/*     file global name                                                      */
/*   classification                                                          */
/*     classification code. This contains a 4 byte value.                    */
/*     A subset of the possible values (defined below) are recognised        */
/*     by the User Interfaces.                                               */
/*     The classification code is divided into a major code (the two         */
/*     higher order bytes) and a minor code (the two lower order bytes).     */
/*     The macros MAJOR_CLASS_CODE() and MINOR_CLASS_CODE() defined          */
/*     below allow to test them.                                             */
/*   dak                                                                     */
/*     data access key for this catalog entry                                */
/*   not_retr                                                                */
/*     True if the file is not retrivable                                    */
/*     false if the file is not retrivable                                   */
/*   not_committed                                                           */
/*     TRUE if the entry is being defined, (e.g.:is not available for        */
/*     any FS/CM verb yet).                                                  */
/*   subtree_token                                                           */
/*     0-based index of the subtree indicator token (DC_NO_SUBTREE if none)  */
/*   attr                                                                    */
/*     token attributes.  Values listed below                                */
/*   description                                                             */
/*     up to 242 characters of text (field padded to 4 byte boundary)        */
/*   desc_ccsid                                                              */
/*     CCSID for description (SNA/FS encoding) - should always = local ccsid */
/*     since SS translates it on receipt                                     */
/*   desc_lang_id                                                            */
/*     SNA/FS encoding of language in which the description was written.     */
/*     This is a 3 byte char field (plus NULL terminator).                   */
/*   utc_ccsid                                                               */
/*     uniform text content CCSID (standard SNA/FS encoding of the code      */
/*     page and character set).  May not equal local ccsid since SS only     */
/*     translates an incoming file if requested to do so.                    */
/*   local_name                                                              */
/*     array of local filenames.  Must be a null-terminated ASCII string.    */
/*     Default directory is the repository.                                  */
/*   compress_state                                                          */
/*     flag indicating state of file.  Values listed below.                  */
/*   compression                                                             */
/*     structure giving name of the compression algorithm and parameters     */
/*   rec_format                                                              */
/*     record format (fixed or variable). Values listed below.               */
/*   max_rec_size                                                            */
/*     maximum record size                                                   */
/*   cf_flags                                                                */
/*     change file flags                                                     */
/*   distributed                                                             */
/*     this boolean field flags whether the file has ever been sent to       */
/*     another SNA/DS node.                                                  */
/*   discovered                                                              */
/*     this boolean field flags whether the catalog entry was created for    */
/*     a Software product discovered by the Inventory Discovery function.    */
/*   pad1                                                                    */
/*     keep Word alignement                                                  */
/*                                                                           */
/*****************************************************************************/

#define DVA_CAT_DESC_TXT    243     /* Allowed length including NUL          */
                                    /* terminator.                           */

#define DVA_CAT_DESC_LEN    (((DVA_CAT_DESC_TXT + 3) / 4) * 4)
                                    /* Length (padded to multiple of 4       */
                                    /* bytes) of buffer required to hold     */
                                    /* description.                          */

typedef struct short_cat_entry
{
  DC_GLOB       glob_name;
  DC_ULONG      classification;
  DC_ULONG      dak;
  DC_USHORT     not_retr;
  DC_USHORT     pad;
  DC_USHORT     not_committed;
  DC_UCHAR      subtree_token;
  DC_CHAR       compress_state;
  DC_CHAR       attr[DVA_NUM_GN_COMP];
  DC_CHAR       description[DVA_DESCR_LEN];
} SHORT_CAT_ENTRY;


typedef struct cat_entry
{
  DC_GLOB       glob_name;
  DC_ULONG      classification;
  DC_ULONG      dak;
  DC_USHORT     not_retr;
  DC_USHORT     pad;
  DC_USHORT     not_committed;
  DC_CHAR       subtree_token;
  DC_CHAR       compress_state;
  DC_CHAR       attr[DVA_NUM_GN_COMP];
  DC_CHAR       description[DVA_CAT_DESC_LEN];
  DC_CHAR       desc_lang_id[DVA_CAT_LANG_LEN];
  DC_USHORT     desc_ccsid;
  DC_USHORT     utc_ccsid;
  DC_ULONG      max_rec_size;
  DC_ULONG      cf_flags;
  DC_FILE_NAME  local_name[DVA_LOCAL_NAME_CNT];
  DC_COMPRESS   compression;
  DC_CHAR       rec_format;
  DC_CHAR       distributed;
  DC_CHAR       discovered;
  DC_CHAR       pad1;
} CAT_ENTRY;

/*****************************************************************************/
/* cf_flags definitions                                                      */
/*****************************************************************************/
#define  CFF_INTERACTIVE         0x00000001
#define  CFF_NOREMOVABLE         0x00000002
#define  CFF_NOACTIVABLE         0x00000004
#define  CFF_CFHISTORYRESET      0x00000008
#define  CFF_CFUNINSTALL         0x00000010
#define  CFF_CFAUTHORIZE         0x00000020
#define  CFF_CFNORETRIEVABLE     0x00000040
#define  CFF_WITH_SECURE_KEY     0x00000080

/*****************************************************************************/
/* The following macros allow to test the major and minor code within        */
/* the classification code                                                   */
/*****************************************************************************/
#define MAJOR_CLASS_CODE(code)  ( (DC_USHORT) ( code >> 16  & 0xffff ) )
#define MINOR_CLASS_CODE(code)  ( (DC_USHORT) ( code & 0xffff ) )

/*****************************************************************************/
/* Structures moved from dvadbcat.h - end                                    */
/*****************************************************************************/

/*****************************************************************************/
/* Products and filesets definitions                                         */
/*****************************************************************************/
#define  MAX_TAG_LEN             145
#define  MAX_REVISION_LEN         65
#define  MAX_ARCHITECTURE_LEN     65
#define  MAX_VENDOR_TAG_LEN       65
#define  MAX_PF_TITLE_LEN        257

/*****************************************************************************/
/* Structure: DC_EXT_PRODUCT                                                 */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used to contain the information related to a product. */
/*   The keyword to access a product in the nvdm DB is given by:             */
/*        tag + revision + architecture + vendot_tag                         */
/* Fields:                                                                   */
/*   tag                                                                     */
/*     Name of the product                                                   */
/*   revision                                                                */
/*     Version, Release, Modification etc. of the product                    */
/*   architecture                                                            */
/*     Operative System etc. where the product run                           */
/*   vendor tag                                                              */
/*     Name of the vendor of the product                                     */
/*   title                                                                   */
/*     Short description of the product                                      */
/*   fileset_descr                                                           */
/*     Descriptor of the data area containing the filesets                   */
/*                                                                           */
/*****************************************************************************/
typedef struct dc_ext_product {
           DC_CHAR         tag[MAX_TAG_LEN];
           DC_CHAR         revision[MAX_REVISION_LEN];
           DC_CHAR         architecture[MAX_ARCHITECTURE_LEN];
           DC_CHAR         vendor_tag[MAX_VENDOR_TAG_LEN];
           DC_CHAR         title[MAX_PF_TITLE_LEN];
} DC_EXT_PRODUCT;

/*****************************************************************************/
/* Structure: DC_EXT_FILESET                                                 */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure is used to contain the information related to a fileset  */
/*   The keyword to access a fileset in the nvdm DB is given by:             */
/*        tag + revision                                                     */
/*                                                                           */
/* Fields:                                                                   */
/*   tag                                                                     */
/*     Name of the fileset                                                   */
/*   revision                                                                */
/*     Version, Release, Modification etc. of the fileset                    */
/*   title                                                                   */
/*     Short description of the fileset                                      */
/*   status                                                                  */
/*     CM status related to fileset                                          */
/*   fseterror                                                               */
/*     file set error field  (values listed below)                           */
/*                                                                           */
/*****************************************************************************/
typedef struct dc_ext_fileset {
           DC_CHAR         tag[MAX_TAG_LEN];
           DC_CHAR         revision[MAX_REVISION_LEN];
           DC_CHAR         title[MAX_PF_TITLE_LEN];
           DC_CHAR         status;
           DC_USHORT       fseterror;
} DC_EXT_FILESET;

#define FS_NOT_DISCOVERED              1


/*****************************************************************************/
/* Structure: REMOTE_DIR                                                     */
/*                                                                           */
/* Overview:                                                                 */
/*     This structure is used by Scheduler to export directories to          */
/*     DIVA targets and by the agent to mount those directories.             */
/*                                                                           */
/* Fields:                                                                   */
/*   server_name                                                             */
/*   exported_dir                                                            */
/*   export_options                                                          */
/*   mounted_fs                                                              */
/*   mount_options                                                           */
/*                                                                           */
/*****************************************************************************/
typedef struct remote_dir
{
  DC_CHAR      server_name[DVA_TRGNAME_LEN];
  DC_FILE_NAME exported_dir;
#define EXPORT_OPTIONS_LEN      64
  DC_CHAR      export_options[EXPORT_OPTIONS_LEN];
  DC_FILE_NAME mounted_fs;
#define MOUNT_OPTIONS_LEN       64
  DC_CHAR      mount_options[MOUNT_OPTIONS_LEN];
  DC_CHAR      pad[16];
} REMOTE_DIR;

#define UC_MAX_RDIR     16


/*****************************************************************************/
/* Values for status field were moved from dvadbcms.h because they           */
/* are used by user exits (cx_vercm)                                         */
/*****************************************************************************/
/*****************************************************************************/
/* Values for status field                                                   */
/*                                                                           */
/* The value CM_FREE is never used in a CM Status record; it is used by DAS  */
/* to mark the fact that a record does not exist.  Users who change status   */
/* values must ensure that CM_FREE is set to a byte value that is not a      */
/* valid status value.                                                       */
/*****************************************************************************/
#define CM_NONE           (DC_CHAR)0    /* no status - not installed         */
#define CM_INSTALL_IP     (DC_CHAR)1    /* install in progress               */
#define CM_I_R_ACTIVE     (DC_CHAR)2    /* installed / removable / active    */
#define CM_I_NR_ACTIVE    (DC_CHAR)3    /* installed / not removable /       */
                                        /* active                            */
#define CM_I_R_INACTIVE   (DC_CHAR)4    /* installed / removable / inactive  */
#define CM_I_NR_INACTIVE  (DC_CHAR)5    /* installed / not removable /       */
                                        /* inactive                          */
#define CM_R_INACTIVE     (DC_CHAR)6    /* removed / inactive                */
#define CM_UI_INACTIVE    (DC_CHAR)7    /* uninstalled / inactive            */
#define CM_I_R_REBOOT     (DC_CHAR)8    /* installed / removable / reboot req*/
#define CM_I_NR_REBOOT    (DC_CHAR)9    /* installed / not removable /reboot */
                                        /*                         required  */
#define CM_DISCOVERED     (DC_CHAR)10   /* CM Status was discovered by       */
                                        /* inventory discovery               */
#define CM_DISTRIBUTED    (DC_CHAR)11   /* File has been distributed to the  */
                                        /* target                            */
#define CM_DIST_PEND      (DC_CHAR)12   /* File is going to be distributed   */
#define CM_FREE           (DC_CHAR)15   /* CM Status record does not exist   */
                                        /* (value used only within DAS)      */

#define CM_STATUS_MASK    (DC_CHAR)15   /* mask for status values            */

#define CM_AUTH_ON_TARG   (DC_CHAR)16   /* Target is authorized to access    */
                                        /* its own copy of the file          */
#define CM_ERROR_STATE    (DC_CHAR)32   /* file is in an indeterminable      */
                                        /* state following a nonrecoverable  */
                                        /* error in an Activate, Accept,     */
                                        /* Remove or Uninstall               */
#define CM_BACK_LEVEL     (DC_CHAR)64   /* file is back-level - this flag is */
                                        /* a duplicate of the CM_TYPE_BKL    */
                                        /* flag in the type field            */
#define CM_AUTH_ON_SERV   (DC_CHAR)128  /* Target is allowed to access       */
                                        /* Servers copy of the file          */

#define CM_CX_AIX_MASK    (DC_CHAR)47   /* Mask for  user exits to hide      */
                                        /* particular bits of the CM_STATUS  */
                                        /* of an AIXINSTP change file        */

/*****************************************************************************/
/* Define max IP and SNA name                                                */
/*****************************************************************************/
#define MAX_IP_NAME_LEN      256
#define MAX_SNA_NAME_LEN     9

/*****************************************************************************/
/* Maximum number of targets from which a user can login                     */
/*****************************************************************************/
#define DVA_MAX_LOGIN_TRGS   16

/*****************************************************************************/
/* Maximum number of installation parameters which can be supplied by a user */
/* exit.                                                                     */
/*****************************************************************************/
#define DVA_MAX_INST_PARMS   10

/*****************************************************************************/
/* Define max IP address length                                              */
/*****************************************************************************/
#define MAX_IPADDR_LEN       16

/*****************************************************************************/
/*                                                                           */
/* Length of a substitution token.                                           */
/*                                                                           */
/* The maximum size of the token name, excluding the $().                    */
/*                                                                           */
/*****************************************************************************/
#define DVA_TOKEN_LEN     12

/*****************************************************************************/
/*                                                                           */
/* Maximum length of the text which can be substituted in place of a token.  */
/*                                                                           */
/*****************************************************************************/
#define DVA_MAX_TOKN_TXT  50

/*****************************************************************************/
/*                                                                           */
/* Length of a LAN Address                                                   */
/*                                                                           */
/* Used in Database File:  DB_LAN_ADDR, DB_TARGET_CONFIG                     */
/*                                                                           */
/* The LAN address is a null terminated string of up to DVA_LANADDR_LEN      */
/* bytes, used by the RBH for verification of incoming connections.          */
/*                                                                           */
/*****************************************************************************/
#define DVA_LANADDR_LEN   32

/*****************************************************************************/
/*                                                                           */
/* Length of a Phone Number Field                                            */
/*                                                                           */
/* Used in Database File:  DB_TARGET_CONFIG, DB_SNADS_CONTROL                */
/*                                                                           */
/* UI will not permit this length to be exceeded.                            */
/*                                                                           */
/* The length includes the terminating NULL.                                 */
/*****************************************************************************/
#define DVA_PHONE_LEN     32

/*****************************************************************************/
/*                                                                           */
/* Length of a Contact Address Field                                         */
/*                                                                           */
/* Used in Database File:  DB_TARGET_CONFIG, DB_SNADS_CONTROL                */
/*                                                                           */
/* UI will not permit this length to be exceeded.                            */
/*                                                                           */
/*                                                                           */
/* The length includes the terminating NULL.                                 */
/*****************************************************************************/
#define DVA_ADDR_LEN     200

#define DVA_MAX_HW_PARM        128

/*****************************************************************************/
/* Maximum length of a telephone number used in an async connection.         */
/*****************************************************************************/
#define DVA_TPHONE_NUM_LEN          40

/*****************************************************************************/
/* Maximum length of an async port name.                                     */
/*****************************************************************************/
#define DVA_PORT_NAME_LEN           20

/*****************************************************************************/
/* Maximum length of an async modem initialisation string.                   */
/*****************************************************************************/
#define DVA_MODEM_INIT_LEN          20

/*****************************************************************************/
/* Maximum length of an async modem dial string.                             */
/*****************************************************************************/
#define DVA_MODEM_DIAL_LEN          20

#ifdef NVDMCLNT
/*****************************************************************************/
/* Client semaphores used by Clint RBX, and initialised by client DACA & UIs.*/
/*****************************************************************************/
#define ASY_MODEM_SEMA4             "ASY_MODEM_SEMA4"
#define ASY_UI_BUSY_SEMA4           "ASY_UI_BUSY_SEMA4"
#define ASY_DACA_BUSY_SEMA4         "ASY_DACA_BUSY_SEMA4"

/*****************************************************************************/
/* Bitwise values used for the 'asy_got_sema4' field in the client DACA and  */
/* CLI Task Work Spaces.                                                     */
/*****************************************************************************/
#define ASY_GOT_NONE                0x00
#define ASY_GOT_MODEM               0x01
#define ASY_GOT_UI_BUSY             0x02
#define ASY_GOT_DACA_BUSY           0x04
#define ASY_CONN_OPEN               0x08
#endif

/* Moved here from fndcotyp.h because used in user exits                     */

/*****************************************************************************/
/* Structure: REQUEST_ID                                                     */
/*                                                                           */
/* Overview:                                                                 */
/*   This structure defines all the fields that uniquely identify a request  */
/*                                                                           */
/* Fields:                                                                   */
/*   user                                                                    */
/*     the name of the user that submitted the request.                      */
/*   server                                                                  */
/*     the name of the server where that user was logged on.                 */
/*   seq_no                                                                  */
/*     sequence number assigned to the request (for each user)               */
/*   recursion_no                                                            */
/*     recursion number of the request                                       */
/*****************************************************************************/
typedef struct request_id
{
   DC_CHAR     user[DVA_USRNAME_LEN];
   DC_CHAR     server[DVA_TRGNAME_LEN];
   DC_ULONG    seq_no;
   DC_USHORT   recursion_no;
   DC_USHORT   pad;
}  REQUEST_ID;

#endif
